@@ -61,7 +61,9 @@ class Client:
         else:
             raise ValueError(f'{server} is not a valid scheme')
 
-        self._authorization = credential.get('Authorization', None)
+        self._authorization = credential.get(
+            'Authorization', os.environ.get('CLIP_AUTH_TOKEN')
+        )
 
     @overload
     def encode(
@@ -205,8 +207,9 @@ class Client:
             request_size=kwargs.get('batch_size', 8),
             total_docs=len(content) if hasattr(content, '__len__') else None,
         )
+
         if self._scheme == 'grpc' and self._authorization:
-            payload.update(metadata=('authorization', self._authorization))
+            payload.update(metadata=(('authorization', self._authorization),))
         elif self._scheme == 'http' and self._authorization:
             payload.update(headers={'Authorization': self._authorization})
         return payload
@@ -413,7 +416,7 @@ class Client:
             total_docs=len(content) if hasattr(content, '__len__') else None,
         )
         if self._scheme == 'grpc' and self._authorization:
-            payload.update(metadata=('authorization', self._authorization))
+            payload.update(metadata=(('authorization', self._authorization),))
         elif self._scheme == 'http' and self._authorization:
             payload.update(headers={'Authorization': self._authorization})
         return payload
